@@ -4,7 +4,7 @@
 #	Class 'ppm' representing fitted point process models.
 #
 #
-#	$Revision: 2.132 $	$Date: 2016/12/19 06:09:50 $
+#	$Revision: 2.134 $	$Date: 2017/07/13 02:03:11 $
 #
 #       An object of class 'ppm' contains the following:
 #
@@ -578,8 +578,9 @@ deviance.ppm <- function(object, ...) {
 
 logLik.ppm <- function(object, ..., new.coef=NULL, warn=TRUE, absolute=FALSE) {
   if(!is.poisson.ppm(object) && warn) 
-    warning(paste("log likelihood is not available for non-Poisson model;",
-                  "log-pseudolikelihood returned"))
+    warn.once("ppmLogLik",
+              "log likelihood is not available for non-Poisson model;",
+              "log pseudolikelihood returned")
   ## degrees of freedom
   nip <- if(!inherits(object, "ippm")) 0 else
            length(attr(object$covfunargs, "free"))
@@ -734,21 +735,49 @@ modelFrameGam <- function(formula, ...) {
 model.matrix.ppm <- function(object,
                              data=model.frame(object, na.action=NULL),
                              ..., Q=NULL, keepNA=TRUE) {
-  data.given <- !missing(data) && !is.null(data)
+  if(missing(data)) data <- NULL			     
+  PPMmodelmatrix(object, data=data, ..., Q=Q, keepNA=keepNA)
+}
+
+model.matrix.ippm <- function(object,
+                              data=model.frame(object, na.action=NULL),
+                              ..., Q=NULL, keepNA=TRUE, irregular=FALSE) {
+  if(missing(data)) data <- NULL			     
+  PPMmodelmatrix(object, data=data, ...,
+                 Q=Q, keepNA=keepNA, irregular=irregular)
+}
+
+PPMmodelmatrix <- function(object,
+                           data=model.frame(object, na.action=NULL),
+                           ..., Q=NULL, keepNA=TRUE, irregular=FALSE) {
+  # handles ppm and ippm			      
+  data.given <- !is.null(data)
+  irregular <- irregular && inherits(object, "ippm") && !is.null(object$iScore)
   if(!is.null(Q)) {
     if(data.given) stop("Arguments Q and data are incompatible")
     if(!inherits(Q, c("ppp", "quad")))
       stop("Q should be a point pattern or quadrature scheme")
     if(is.ppp(Q)) Q <- quad(Q, Q[FALSE])
     ## construct Berman-Turner frame
-    needed <- c("trend", "interaction", "covariates", "correction", "rbord")
+    needed <- c("trend", "interaction", "covariates", "covfunargs",
+                "correction", "rbord")
     bt <- do.call(bt.frame, append(list(Q), object[needed]))
     ## compute model matrix
     mf <- model.frame(bt$fmla, bt$glmdata, ...)
     mm <- model.matrix(bt$fmla, mf, ...)
+    if(irregular) {
+       ## add irregular score components
+       U <- union.quad(Q)
+       mi <- sapply(object$iScore, do.call,
+                    args=append(list(x=U$x, y=U$y), object$covfunargs),
+		    envir=environment(terms(object)))
+       if(nrow(mi) != nrow(mm))
+         stop("Internal error: incorrect number of rows in iScore")
+       mm <- cbind(mm, mi)
+    }
     ## remove NA's ?
     if(!keepNA)
-      mm <- mm[complete.cases(mm), ..., drop=FALSE]
+      mm <- mm[complete.cases(mm), , drop=FALSE]
     return(mm)
   }
   gf <- getglmfit(object)
@@ -766,13 +795,26 @@ model.matrix.ppm <- function(object,
     if(any(forgot <- !(names(bt) %in% names(data)))) 
       data <- do.call(cbind, append(list(data), bt[forgot]))
     mm <- model.matrix(gf, data=data, ...)
+    if(irregular) {
+       ## add irregular score components 
+       mi <- sapply(object$iScore, do.call,
+                    args=append(list(x=data$x, y=data$y), object$covfunargs),
+		    envir=environment(terms(object)))
+       if(nrow(mi) != nrow(mm))
+         stop("Internal error: incorrect number of rows in iScore")
+       mm <- cbind(mm, mi)
+    }
+    if(inherits(gf, "gam")) 
+      attr(mm, "assign") <- gf$assign
     return(mm)
   }
 
-  if(!keepNA) {
+  if(!keepNA && !irregular) {
     # extract model matrix of glm fit object
     # restricting to its 'subset' 
     mm <- model.matrix(gf, ...)
+    if(inherits(gf, "gam")) 
+      attr(mm, "assign") <- gf$assign
     return(mm)
   }
   
@@ -793,6 +835,21 @@ model.matrix.ppm <- function(object,
     } else 
     stop("internal error: model matrix does not match glm data frame")
   }
+  if(irregular) {
+     ## add irregular score components 
+     U <- union.quad(quad.ppm(object, drop=FALSE))
+     mi <- sapply(object$iScore, do.call,
+                  args=append(list(x=U$x, y=U$y), object$covfunargs),
+		  envir=environment(terms(object)))
+     if(nrow(mi) != nrow(mm))
+       stop("Internal error: incorrect number of rows in iScore")
+     mm <- cbind(mm, mi)
+     cn <- c(cn, colnames(mi))
+  }
+  if(!keepNA)
+    mm <- mm[complete.cases(mm), , drop=FALSE]
+  if(inherits(gf, "gam")) 
+    attr(mm, "assign") <- gf$assign
   colnames(mm) <- cn
   return(mm)
 }
@@ -803,10 +860,11 @@ model.images <- function(object, ...) {
 
 model.images.ppm <- function(object, W=as.owin(object), ...) {
   X <- data.ppm(object)
+#  irregular <- resolve.1.default(list(irregular=FALSE), list(...))
   ## make a quadscheme with a dummy point at every pixel
   Q <- pixelquad(X, W)
   ## compute model matrix
-  mm <- model.matrix(object, Q=Q)
+  mm <- model.matrix(object, Q=Q, ...)
   ## retain only the entries for dummy points (pixels)
   mm <- mm[!is.data(Q), , drop=FALSE]
   mm <- as.data.frame(mm)
